Skip to contents

Add socioeconomic status as a column to a table using the Index of Multiple Deprivation

Usage

addIndexOfMultipleDeprivation(
  x,
  indexDate = "cohort_start_date",
  window = c(-Inf, Inf),
  order = "last",
  nameStyle = "socio_economic_status",
  name = tableName(x),
  missingSocioEconomicStatusValue = "Missing"
)

Arguments

x

A cdm_table containing a person identifier column named person_id or subject_id.

indexDate

A character string naming the Date column in x that defines the index date.

window

A numeric vector of length two, c(min, max), defining the window for socio_economic_status in days relative to indexDate. Use -Inf or Inf for an unbounded lower or upper limit.

order

A character string specifying which record to select when multiple records are found: first or last.

nameStyle

A character string specifying the name of the new column.

name

A character string specifying the name of the output table. If NULL, a temporary table is created.

missingSocioEconomicStatusValue

A character string used to replace missing socioeconomic status values.

Value

The table x with a new column containing the Index of Multiple Deprivation value.

Examples

# \donttest{
library(omock)
library(duckdb)
library(OmopIndices)
library(dplyr)
library(CohortConstructor)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
#> ℹ Loading bundled GiBleed tables from package data.
#> ℹ Adding drug_strength table.
#> ℹ Creating local <cdm_reference> object.
#> ℹ Inserting <cdm_reference> into duckdb.
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#> ℹ /tmp/RtmpNEUAUi/duckdb
#> This is removed when the R session ends.
#> • Extensions are re-downloaded each session.
#> • Secrets are lost.
#> ℹ Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#> ℹ Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#> ℹ See ?duckdb_storage for details and alternatives.
cdm$cohort <- conceptCohort(
  cdm = cdm,
  conceptSet = list(sinusitis = c(257012L, 4283893L, 4294548L, 40481087L)),
  name = "cohort"
)
#> ℹ Subsetting table condition_occurrence using 4 concepts with domain:
#>   condition.
#> ℹ Combining tables.
#> ℹ Creating cohort attributes.
#> ℹ Applying cohort requirements.
#> ℹ Merging overlapping records.
#> ✔ Cohort cohort created.

cdm$cohort |>
  addIndexOfMultipleDeprivation() |>
  select(subject_id, cohort_start_date, socio_economic_status) |>
  glimpse()
#> ℹ Trying to add Socio-economic status from imd.
#> ! Socio-economic status could not be added from imd.
#> Rows: ??
#> Columns: 3
#> $ subject_id            <int> 4224, 4224, 4488, 4527, 4527, 4569, 4847, 5000, …
#> $ cohort_start_date     <date> 1965-01-06, 1968-12-13, 2001-10-03, 1980-06-10,…
#> $ socio_economic_status <chr> "Missing", "Missing", "Missing", "Missing", "Mis…
# }