Skip to contents

Get the codelists used for a specified index calculation

Usage

getIndexCodelist(index)

Arguments

index

A character string identifying the index for which to retrieve internal codelists. Supported values are "body_mass_index", "charlson", "electronic_frailty_index", "hospital_frailty_risk_score", and "updated_charlson".

Value

A codelist containing the concepts used for the selected index.

Examples

library(OmopIndices)

getIndexCodelist("charlson")
#> 
#> ── 17 codelists ────────────────────────────────────────────────────────────────
#> 
#> - aids (11 codes)
#> - any_malignancy (716 codes)
#> - cerebrovascular_disease (129 codes)
#> - chronic_pulmonary_disease (92 codes)
#> - congestive_heart_failure (41 codes)
#> - connective_tissue_disease (60 codes)
#> along with 11 more codelists