Add Body Mass Index measurement
Arguments
- x
A
cdm_tableobject, it mus containperson_idorsubject_idas columns.- conceptSet
It can either be a
, <codelist_with_details> or <concept_set_expression> object. It must contain obesity,bmias concepts. IfNULLconcepts will be retrieved using the OmopConcepts package.- indexDate
A character string that points to a
Datecolumn in thextable.- window
Window to asses
obesityin, it must be a vector of two numeric valuesc(min, max). Window times refer to days sinceindexDate.- order
A character vector with the options to deal with multiple values per person:
last: Latest value within the window.first: First value within the window.max: Maximum value within the window.min: Minimum value within the window.
- nameStyle
A character string with the name of the new column.
- categories
List to group the
bmirecords into categories.- name
A character string with the name of the new table. If
NULLa temporary table will be created.