Add Charlson index value
Arguments
- x
A
cdm_tableobject, it mus containperson_idorsubject_idas columns.- indexDate
A character string that points to a
Datecolumn in thextable.- window
Window to asses
Charlson indexin, it must be a vector of two numeric valuesc(min, max). Window times refer to days sinceindexDate.- conceptSet
It can either be a
, <codelist_with_details> or <concept_set_expression> object. It must contain myocardial_infarction,congestive_heart_failure,peripheral_vascular_disease,cerebrovacular_accident,transient_ischemic_attack,dementia,chronic_pulmonary_disease,connective_tissue_disease,peptic_ulcer_disease,mild_liver_disease,severe_liver_disease,diabetes_mellitus,end_organ_diabetes_mellitus,hemiplegia,estimated_glomerular_filtration_rate,severe_chronic_kidney_disease,localised_solid_tumor,metastatic_solid_tumor,leukemia,lymphoma,aidsas concepts. IfNULLconcepts will be retrieved using the OmopConcepts package.- nameStyle
A character string with the name of the new column.
- name
A character string with the name of the new table. If
NULLa temporary table will be created.