Add socioeconomic status as a column to a table using the Index of Multiple Deprivation
Source:R/socioEconomicStatus.R
addIndexOfMultipleDeprivation.RdAdd socioeconomic status as a column to a table using the Index of Multiple Deprivation
Arguments
- x
A
cdm_tablecontaining a person identifier column namedperson_idorsubject_id.- indexDate
A character string naming the
Datecolumn inxthat defines the index date.- window
A numeric vector of length two,
c(min, max), defining the window forsocio_economic_statusin days relative toindexDate. Use-InforInffor an unbounded lower or upper limit.- order
A character string specifying which record to select when multiple records are found:
firstorlast.- nameStyle
A character string specifying the name of the new column.
- name
A character string specifying the name of the output table. If
NULL, a temporary table is created.- missingSocioEconomicStatusValue
A character string used to replace missing socioeconomic status values.
Examples
# \donttest{
library(omock)
library(duckdb)
library(OmopIndices)
library(dplyr)
library(CohortConstructor)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
#> ℹ Loading bundled GiBleed tables from package data.
#> ℹ Adding drug_strength table.
#> ℹ Creating local <cdm_reference> object.
#> ℹ Inserting <cdm_reference> into duckdb.
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#> ℹ /tmp/Rtmplwnqmn/duckdb
#> This is removed when the R session ends.
#> • Extensions are re-downloaded each session.
#> • Secrets are lost.
#> ℹ Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#> ℹ Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#> ℹ See ?duckdb_storage for details and alternatives.
cdm$cohort <- conceptCohort(
cdm = cdm,
conceptSet = list(sinusitis = c(257012L, 4283893L, 4294548L, 40481087L)),
name = "cohort"
)
#> ℹ Subsetting table condition_occurrence using 4 concepts with domain:
#> condition.
#> ℹ Combining tables.
#> ℹ Creating cohort attributes.
#> ℹ Applying cohort requirements.
#> ℹ Merging overlapping records.
#> ✔ Cohort cohort created.
cdm$cohort |>
addIndexOfMultipleDeprivation() |>
select(subject_id, cohort_start_date, socio_economic_status) |>
glimpse()
#> ℹ Trying to add Socio-economic status from imd.
#> ! Socio-economic status could not be added from imd.
#> Rows: ??
#> Columns: 3
#> $ subject_id <int> 4855, 4975, 5086, 5232, 5252, 5252, 227, 376, 67…
#> $ cohort_start_date <date> 1986-02-13, 1968-08-16, 1981-03-17, 1981-12-21,…
#> $ socio_economic_status <chr> "Missing", "Missing", "Missing", "Missing", "Mis…
# }