Get the codelists used for a specified index calculation
Source:R/indexConcepts.R
getIndexCodelist.RdGet the codelists used for a specified index calculation
Examples
library(OmopIndices)
getIndexCodelist("charlson")
#>
#> ── 17 codelists ────────────────────────────────────────────────────────────────
#>
#> - aids (11 codes)
#> - any_malignancy (716 codes)
#> - cerebrovascular_disease (129 codes)
#> - chronic_pulmonary_disease (92 codes)
#> - congestive_heart_failure (41 codes)
#> - connective_tissue_disease (60 codes)
#> along with 11 more codelists